package com.sqx.modules.gameChat.service;


import com.baomidou.mybatisplus.extension.service.IService;
import com.sqx.common.utils.PageUtils;
import com.sqx.common.utils.Result;
import com.sqx.modules.gameChat.entity.ChatContentTcwm;


public interface ChatContentTcwmService extends IService<ChatContentTcwm> {

    PageUtils selectChatContentPage(Integer page, Integer limit, Long chatConversationId, String content);

    int updateChatContentStatusByUserIdAndChatId(Long userId,Long chatConversationId);

    int selectChatCount(Long userId);

    Result selectOrdersChatPage(Integer page, Integer limit, Long userId, Long riderId, Long shopId);

    Result selectOrdersChatList(Integer page, Integer limit, String userName);

    Result selectGameChatDetails(Integer page, Integer limit,Long ordersId, Integer type);

    Result selectGameChatList(Integer page, Integer limit,String userName,String content,Long ordersId);

    Result selectUnreadMessage(Long ordersId, Integer type);

    Result selectAllUnreadCount(Long userId, Long riderUserId, Long shopId);

    Result updateShopAllUnreadCount(Long userId, Long riderUserId, Long shopId);
}
